# About
**slupy** is a library that serves a variety of utility/helper functionality (in Python) built on the standard library.

## Installation
- Can be installed via `pip install slupy` or `pip install slupy==<version>`

## Documentation
- The documentation for the `slupy` package can be found in the `docs/` folder (based on the version). You can view the respective HTML file (`docs/version-xxx/index.html`) in your browser after cloning/downloading this repository.
